@@ -37,7 +37,11 @@ sub to_hash {
    return $hash;
 }
 
-
+sub num_coupons {
+    my $self = shift;
+    my $results = shift;
+    return scalar @{ $results->{coupon} };
+}
 
 
 1
